@@ -46,7 +46,7 @@ L<AnyEvent>
 =item *
 
 L<IO::Async>
- 
+
 =back
 
 Support
@@ -55,7 +55,7 @@ but has not materialized yet.
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 our @loops = (
     ['IO/Async.pm'    => 'Future::HTTP::NetAsync' ],
@@ -69,7 +69,7 @@ our @loops = (
     # interesting problems. How will we load this? We have two prerequisites
     # now, threads.pm and HTTP::Tiny...
     ['threads.pm' => 'Future::HTTP::Tiny::threaded' ],
-    
+
     ['HTTP/Tiny/Paranoid.pm' => 'Future::HTTP::Tiny::Paranoid'],
 
     # The fallback, will always catch due to loading Future::HTTP
@@ -89,13 +89,13 @@ Creates a new instance of the HTTP client.
 
 sub new($factoryclass, @args) {
     $implementation ||= $factoryclass->best_implementation();
-    
+
     # return a new instance
     $implementation->new(@args);
 }
 
 sub best_implementation( $class, @candidates ) {
-    
+
     if(! @candidates) {
         @candidates = @loops;
     };
@@ -109,7 +109,7 @@ sub best_implementation( $class, @candidates ) {
     } grep {
         $INC{$_->[0]}
     } @candidates;
-    
+
     # Check which one we can load:
     for my $impl (@applicable_implementations) {
         if( eval "require $impl; 1" ) {
@@ -186,8 +186,8 @@ L<AnyEvent::HTTP> for the details of the API
 
 =head1 REPOSITORY
 
-The public repository of this module is 
-L<http://github.com/Corion/future-http>.
+The public repository of this module is
+L<https://github.com/Corion/future-http>.
 
 =head1 SUPPORT
 
@@ -206,7 +206,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2017 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2018 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
