@@ -12,7 +12,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 with 'Future::HTTP::Handler';
 
@@ -40,7 +40,9 @@ sub http_request($self,$method,$url,%options) {
         return $self->future_from_result($body, $headers);
     });
 
-    AnyEvent::HTTP::http_request($method => $url, %options, sub ($body, $headers) {
+    my $r;
+    $r = AnyEvent::HTTP::http_request($method => $url, %options, sub ($body, $headers) {
+        undef $r;
         $res->done( $body,$headers )
     });
 
@@ -140,7 +142,7 @@ L<AnyEvent::HTTP> for the details of the API
 =head1 REPOSITORY
 
 The public repository of this module is
-L<http://github.com/Corion/future-http>.
+L<https://github.com/Corion/future-http>.
 
 =head1 SUPPORT
 
@@ -159,7 +161,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2017 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2018 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
