@@ -7,7 +7,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 with 'Future::HTTP::Handler';
 
@@ -210,7 +210,7 @@ L<AnyEvent::HTTP> for the details of the API
 =head1 REPOSITORY
 
 The public repository of this module is 
-L<http://github.com/Corion/future-http>.
+L<https://github.com/Corion/future-http>.
 
 =head1 SUPPORT
 
@@ -229,7 +229,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2017 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2018 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
